<?php

/**
  * SquirrelMail Vacation Local Plugin
  * Copyright (c) 2004-2005 Jonathan Bayer <jbayer@spamcop.net>,
  *                         Paul Lesneiwski <pdontthink@angrynerds.com>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage Vacation Local
  *
  */



/**
  * Inserts link to the vacation configuration page
  * in options page
  *
  */
function vacation_option_link_do() 
{

   global $optpage_blocks;

   bindtextdomain ('vacation_local', SM_PATH . 'locale');
   textdomain ('vacation_local');

   $optpage_blocks[] = array(
      'name' => _("Vacation Message"),
      'url' => SM_PATH . 'plugins/vacation_local/vac_init.php',
      'desc' => _("Set up an auto-reply message and optionally forward your incoming email. This can be useful when you are away on vacation."),
      'js' => FALSE
   );

   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
   textdomain ('squirrelmail');

}


?>